Struct Val

pub struct Val { /* private fields */ }
A wrapper around a javascript handle

Implementations

Source

impl Val

pub fn take_ownership(handle: Handle) -> Val

Takes the ownership of a handle

pub fn from_val(v: Val) -> Self

Creates a Val object from another

pub fn global_this() -> Val

Returns the globalThis object

pub fn get<T: Into<Val>>(&self, prop: T) -> Val

Gets the property prop

Examples found in repository?
examples/dom.rs (line 15)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (line 17)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn global(name: &str) -> Val

Gets a global object by name

Examples found in repository?
examples/dom.rs (line 4)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (line 5)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn null() -> Val

Gets a js null Val

pub fn undefined() -> Val

Gets a js undefined Val

Examples found in repository?
examples/dom.rs (line 21)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (line 32)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn object() -> Val

Gets a new js object

pub fn array() -> Val

Gets a new js array

pub fn from_i32(i: i32) -> Val

Creates a Val from an i32

pub fn from_f64(f: f64) -> Val

Creates a Val from an f64

pub fn from_str(s: &str) -> Val

Creates a Val from str

pub fn as_handle(&self) -> Handle

Returns the raw js handle

pub fn set<K: Into<Val>, V: Into<Val>>(&self, prop: K, val: V)

Set the underlying js object property prop to val

Examples found in repository?
examples/dom.rs (line 6)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (line 16)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn has<T: Into<Val>>(&self, prop: T) -> bool

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T: Into<Val>>(&self, idx: T) -> Val

Gets the element at index idx. Assumes the underlying js type is indexable

Examples found in repository?
examples/dom.rs (line 7)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (line 22)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn as_i32(&self) -> i32

Gets the underlying i32 value of a js object

Examples found in repository?
examples/dom.rs (line 18)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
pub fn as_bool(&self) -> bool

Gets the underlying boolean value of a js object

Examples found in repository?
examples/audio.rs (line 6)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn as_f64(&self) -> f64

Gets the underlying f64 value of a js object

pub fn as_string(&self) -> String

Gets the underlying string value of a js object

pub fn to_vec_i32(&self) -> Vec<i32>

Converts the underlying js array to an Vec of i32

pub fn to_vec_f64(&self) -> Vec<f64>

Converts the underlying js array to an Vec of f64

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

Examples found in repository?
examples/dom.rs (line 5)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (line 13)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

Examples found in repository?
examples/audio.rs (line 12)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn make_fn_raw(f: fn(Handle, Handle) -> Handle, data: Handle) -> Val

Creates js function from a function pointer and returns its handle wrapped in a Val object

pub fn make_fn<F: FnMut(&[Val]) -> Val>(cb: F) -> Val

Creates a js function from a Rust closure and returns a Val

Examples found in repository?
examples/dom.rs (lines 12-22)
3fn main() {
4    let document = Val::global("document");
5    let elem = document.call("createElement", &argv!["BUTTON"]);
6    elem.set("textContent", Val::from("Click"));
7    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
8    elem.call(
9        "addEventListener",
10        &argv![
11            "click",
12            Val::make_fn(|ev| {
13                let console = Console::get();
14                console.call("clear", &[]);
15                console.log(&[ev[0].get("clientX")]);
16                println!(
17                    "client x: {}",
18                    ev[0].get("clientX").as_i32()
19                );
20                println!("hello from Rust");
21                Val::undefined()
22            })
23        ],
24    );
25    body.call("appendChild", &argv![elem]);
26}
More examples
Hide additional examples
examples/audio.rs (lines 27-33)
3fn main() {
4    #[allow(non_snake_case)]
5    let mut AudioContext = Val::global("AudioContext");
6    if !AudioContext.as_bool() {
7        println!("No global AudioContext, trying webkitAudioContext");
8        AudioContext = Val::global("webkitAudioContext");
9    }
10
11    println!("Got an AudioContext");
12    let context = AudioContext.new(&[]);
13    let oscillator = context.call("createOscillator", &[]);
14
15    println!("Configuring oscillator");
16    oscillator.set("type", "triangle");
17    oscillator.get("frequency").set("value", Val::from(261.63)); // Middle C
18
19    let document = Val::global("document");
20    let elem = document.call("createElement", &argv!["BUTTON"]);
21    elem.set("textContent", "Click");
22    let body = document.call("getElementsByTagName", &argv!["body"]).at(0);
23    elem.call(
24        "addEventListener",
25        &argv![
26            "click",
27            Val::make_fn(move |_| {
28                println!("Playing");
29                oscillator.call("connect", &argv![context.get("destination")]);
30                oscillator.call("start", &argv![0]);
31                println!("All done!");
32                Val::undefined()
33            })
34        ],
35    );
36    body.call("appendChild", &argv![elem]);
37}
pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn delete(v: Val)

Decrements the refcount of the underlying handle

pub fn throw(v: Val)

Throws a js object represented by Val

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v